#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import sys
import logging
import traceback
import pypinyin
from pypinyin import lazy_pinyin
from gm_types.gaia import SERVICE_ITEM_PRICE_TYPE, DOCTOR_TYPE
import uuid




def uuid4():
    """

    :return:
    """
    return uuid.uuid4().hex

def get_tips_suggest_list(instance_cn_name):
    try:
        ch_full_weight = 6.0 * 10000
        py_full_weight = 3.0 * 10000
        py_acronym_full_weight = 3.0 * 10000

        py_acronym_prefix_weight = 2
        ch_prefix_weight = 1.5
        py_prefix_weight = 1.0

        # 命中开始部分加权
        begin_prefix_weight = 1.2 * 10000

        ch_full_word = instance_cn_name.strip()
        py_full_word = ''.join(lazy_pinyin(ch_full_word))
        py_acronym_full_word = ''.join(lazy_pinyin(ch_full_word, style=pypinyin.FIRST_LETTER))

        suggest_list = list()
        cur_index = 0
        # 中文
        for i in range(len(ch_full_word)):
            for j in range(i, len(ch_full_word) + 1):
                ch_name_term = ch_full_word[i:j].strip()
                if ch_name_term:
                    prefix_weight = ch_prefix_weight if len(ch_name_term) != len(
                        ch_full_word) else ch_full_weight
                    suggest_type = 0 if len(ch_name_term) != len(ch_full_word) else 1
                    term_begin_prefix_weight = begin_prefix_weight if i == 0 else 1.0
                    suggest_item = {
                        "input": [ch_name_term],
                        "word_weight": (1.0 * len(ch_name_term) / len(
                            (ch_full_word))) * prefix_weight * term_begin_prefix_weight,
                        "suggest_type": suggest_type,
                        "cur_index": cur_index
                    }
                    cur_index += 1
                    suggest_list.append(suggest_item)

        # 拼音
        for i in range(len(py_full_word)):
            for j in range(i, len(py_full_word) + 1):
                py_name_term = py_full_word[i:j].strip()
                if py_name_term:
                    prefix_weight = py_prefix_weight if len(py_name_term) != len(
                        py_full_word) else py_full_weight
                    suggest_type = 2 if len(py_name_term) != len(py_full_word) else 3
                    term_begin_prefix_weight = begin_prefix_weight if i == 0 else 1.0
                    suggest_item = {
                        "input": [py_name_term],
                        "word_weight": (1.0 * len(py_name_term) / len(
                            py_full_word)) * prefix_weight * term_begin_prefix_weight,
                        "suggest_type": suggest_type,
                        "cur_index": cur_index
                    }
                    cur_index += 1
                    suggest_list.append(suggest_item)

        # 简写
        for i in range(len(py_acronym_full_word)):
            for j in range(i, len(py_acronym_full_word) + 1):
                py_acronym_term = py_acronym_full_word[i:j].strip()
                if py_acronym_term:
                    prefix_weight = py_acronym_prefix_weight if len(py_acronym_term) != len(
                        py_acronym_full_word) else py_acronym_full_weight
                    suggest_type = 4 if len(py_acronym_term) != len(py_acronym_full_word) else 5
                    term_begin_prefix_weight = begin_prefix_weight if i == 0 else 1.0
                    suggest_item = {
                        "input": [py_acronym_term],
                        "word_weight": (1.0 * len(py_acronym_term) / len(
                            py_acronym_full_word)) * prefix_weight * term_begin_prefix_weight,
                        "suggest_type": suggest_type,
                        "cur_index": cur_index
                    }
                    cur_index += 1
                    suggest_list.append(suggest_item)

        return suggest_list
    except:
        logging.error("catch exception,err_msg:%s" % traceback.format_exc())
        return list()

